searchData={"items":[{"type":"task","title":"mix kubegen","doc":"(Re-)Generates clients for Kubernetes resources according to the config.","ref":"Mix.Tasks.Kubegen.html"},{"type":"task","title":"Configuration - mix kubegen","doc":"Prior to running this Mix task, you need to create a configuration in your\n`config.exs` under `config :kubegen, :default` or `config :kubegen, :mycluster`.\nwhere a custom `:mycluster` identifier is passed as argument\n(`mix kubegen -c mycluster`)\n\n* `:module_prefix` - The prefix of the generated modules (e.g. `MyApp.K8sClient`)\n* `:kubeconfig_pipeline` -  The `Pluggable` pipeline responsible for loading the Kubernetes config. (e.g. `Kubereq.Kubeconfig.Default`)\n* `:resources` - List of resources for which clients are generated.\n\nThe entries of `:resources` can be in the form of\n\n* Group-Version-Kind in the case of Kubernetes core resources.\n* Path to a local CRD YAML (multiple CRDs in one file are supported)\n* URL to a public remote CRD Yaml (multiple CRDs in one file are supported)\n\n#","ref":"Mix.Tasks.Kubegen.html#module-configuration"},{"type":"task","title":"Example - mix kubegen","doc":"```\nconfig :kubegen, :default,\n  module_prefix: MyApp.K8sClient,\n  kubeconfig_pipeline: Kubereq.Kubeconfig.Default,\n  resources: [\n    \"v1/ConfigMap\",\n    \"rbac.authorization.k8s.io/v1/ClusterRole\",\n    \"test/support/foos.example.com.yaml\", # local CRD\n    \"https://raw.githubusercontent.com/mruoss/kompost/main/priv/manifest/postgresdatabase.crd.yaml\" # public remote CRD\n  ]\n```\n\n#","ref":"Mix.Tasks.Kubegen.html#module-example"},{"type":"task","title":"How to find the correct Group-Version-Kind identifier - mix kubegen","doc":"Use `mix kubegen.search` to search for GVKs (e.g. `mix.kubegen.search Pod`)","ref":"Mix.Tasks.Kubegen.html#module-how-to-find-the-correct-group-version-kind-identifier"},{"type":"task","title":"mix kubegen.search","doc":"Search Group-Version-Kind (GVK) for Core Resources.\nKubegen requires you to pass GVK as keys in `config.exs`. This mix tasks\nlets you search for GVK for a specific resource kind.\n\n#","ref":"Mix.Tasks.Kubegen.Search.html"},{"type":"task","title":"Example - mix kubegen.search","doc":"mix kubegen.search Pod","ref":"Mix.Tasks.Kubegen.Search.html#module-example"},{"type":"extras","title":"Kubegen","doc":"# Kubegen\n\nGenerate resource based Kubernetes clients with `Kubegen`.\n\n[![Module Version](https://img.shields.io/hexpm/v/kubegen.svg)](https://hex.pm/packages/kubegen)\n[![Last Updated](https://img.shields.io/github/last-commit/mruoss/kubegen.svg)](https://github.com/mruoss/kubegen/commits/main)\n\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/kubegen/)\n[![Total Download](https://img.shields.io/hexpm/dt/kubegen.svg)](https://hex.pm/packages/kubegen)\n[![License](https://img.shields.io/hexpm/l/kubegen.svg)](https://github.com/mruoss/kubegen/blob/main/LICENSE.md)","ref":"readme.html"},{"type":"extras","title":"Installation - Kubegen","doc":"`kubegen` is a code generator. Add the package as dev dependency. Make sure to  \nadd `kubereq` to your list of dependencies as well:\n\n```elixir\ndef deps do\n  [\n    {:kubegen, \"~> 0.1.0\", only: :dev, runtime: false},\n    {:kubereq, \"~> 0.1.0\"}\n  ]\nend\n```\n\nThe docs can be found at  .","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - Kubegen","doc":"Before you can generate clients, you need to create a configuration in your\n`config.exs` under `config :kubegen, :default` or `config :kubegen, :mycluster`.\nwhere a custom `:mycluster` identifier is passed as argument\n(`mix kubegen -c mycluster`)\n\n- `:module_prefix` - The prefix of the generated modules (e.g. `MyApp.K8sClient`)\n- `:kubeconfig_pipeline` - The `Pluggable` pipeline responsible for loading the Kubernetes config. (e.g. `Kubereq.Kubeconfig.Default`)\n- `:resources` - List of resources for which clients are generated.\n\nThe entries of `:resources` can be in the form of\n\n- Group-Version-Kind in the case of Kubernetes core resources.\n- Path to a local CRD YAML (multiple CRDs in one file are supported)\n- URL to a public remote CRD Yaml (multiple CRDs in one file are supported)\n\n#","ref":"readme.html#configuration"},{"type":"extras","title":"Example - Kubegen","doc":"```ex\nconfig :kubegen, :default,\n  module_prefix: MyApp.K8sClient,\n  kubeconfig_pipeline: Kubereq.Kubeconfig.Default,\n  resources: [\n    \"v1/ConfigMap\",\n    \"rbac.authorization.k8s.io/v1/ClusterRole\",\n    \"test/support/foos.example.com.yaml\", # local CRD\n    \"https://raw.githubusercontent.com/mruoss/kompost/main/priv/manifest/postgresdatabase.crd.yaml\" # public remote CRD\n  ]\n```\n\n#","ref":"readme.html#example"},{"type":"extras","title":"How to find the correct Group-Version-Kind identifier - Kubegen","doc":"Use `mix kubegen.search` to search for GVKs (e.g. `mix.kubegen.search Pod`)\n\n#","ref":"readme.html#how-to-find-the-correct-group-version-kind-identifier"},{"type":"extras","title":"Generate Resource Clients - Kubegen","doc":"Now you can (re-)generate clients using `mix kubegen` or `mix kubegen -c mycluster`","ref":"readme.html#generate-resource-clients"},{"type":"extras","title":"Using the generated Clients - Kubegen","doc":"`kubegen` creates a module per resource and subresource. Each resource is\ngeneraated with functions for the operations applicable to that resource. The\ngenerated functions also come with `@doc` documentations.\n\n#","ref":"readme.html#using-the-generated-clients"},{"type":"extras","title":"ConfigMap Example - Kubegen","doc":"You can use `apply/3` or `create/2` to create a new resource:\n\n```ex\nimport YamlElixir.Sigil\nalias MyApp.K8sClient.Core.V1.ConfigMap\n\nConfigMap.apply(~y\"\"\"\napiVersion: v1\nkind: ConfigMap\nmetadata:\n  namespace: default\n  name: my-config\n  labels:\n    app: my-app\ndata:\n  foo: bar\n\"\"\")\n```\n\nTo retrieve a resource, use `get/2`:\n\n```ex\nConfigMap.get(\"default\", \"my-config\")\n```\n\nUse `list/0` or `list/1` to list resources of that kind in all namespaces or\n`list/2` to list resources in a specific namespace. Label or field selectors can\nbe passed as option if needed.\n\n```ex\nConfigMap.list(\"default\", label_selectors: [{\"app\", \"my-app\"}])\n```\n\n`delete/2` and `delete_all/2` delete a single or multiple resources (whereas the\nlatter also supports selectors).\n\n```ex\nConfigMap.delete(\"default\", \"my-config\")\nConfigMap.delete_all(\"default\", label_selectors: [{\"app\", \"my-app\"}])\n```\n\nThere are more functions like `update/1`, `json_path/3`, `merge_patch/3`,\n`watch/N`, `watch_single/3` `wait_until/4`. Checkout the generated modules for\ntheir documentation.","ref":"readme.html#configmap-example"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).","ref":"changelog.html"},{"type":"extras","title":"0.1.1 - Changelog","doc":"#","ref":"changelog.html#0-1-1"},{"type":"extras","title":"Fixed - Changelog","doc":"- License was wrong in `mix.exs`","ref":"changelog.html#fixed"},{"type":"extras","title":"Unreleased - Changelog","doc":"<!-- Add your changelog entry to the relevant subsection -->\n\n<!-- #","ref":"changelog.html#unreleased"},{"type":"extras","title":"Added | Changed | Deprecated | Removed | Fixed | Security --> - Changelog","doc":"<!-- No new entries below this line! -->","ref":"changelog.html#added-changed-deprecated-removed-fixed-security"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}